@@ -339,7 +339,7 @@ class ConvertV3toDsdlYaml:
                     _, sample = self.write_single_sample(sample)
                     sample_list.append(sample)
                 with open(out_file + "_samples.json", "w") as f:
-                    json.dump(sample_list, f)
+                    json.dump({"samples": sample_list}, f)
 
     def write_single_sample(self, sample):
         """提取sample信息，并格式化写入yaml或json文件
@@ -447,7 +447,7 @@ class ConvertV3toDsdlYaml:
             root_path = os.path.dirname(self.dataset_path)
             self.output_path = os.path.join(root_path, temp + "_dsdl")
         if not os.path.exists(self.output_path):
-            os.mkdir(self.output_path)
+            os.makedirs(self.output_path)
         self.get_dataset_info()
         file_name = os.path.join(self.dataset_path, "annotations", "json")
         file_list = os.listdir(path=file_name)
